==> haskell-docopt-0.7.0.8-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 docopt
version:              0.7.0.8
visibility:           public
id:                   docopt-0.7.0.8-IrOaa3HMLz06tqu2H7vILi
key:                  docopt-0.7.0.8-IrOaa3HMLz06tqu2H7vILi
license:              MIT
copyright:            (c) 2013-2015 Ryan Artecona
maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               Ryan Artecona
homepage:             https://github.com/docopt/docopt.hs
synopsis:             A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.

category:             Console
abi:                  d9b8ea070e6814443733b7d6d3d8fbe6
exposed:              True
exposed-modules:      System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules:
    System.Console.Docopt.ApplicativeParsec
    System.Console.Docopt.ParseUtils System.Console.Docopt.Types
    System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
    System.Console.Docopt.Public System.Console.Docopt.QQ
    System.Console.Docopt.QQ.Instances

import-dirs:          /usr/lib/ghc-9.2.8/site-local/docopt-0.7.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/docopt-0.7.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-docopt
hs-libraries:         HSdocopt-0.7.0.8-IrOaa3HMLz06tqu2H7vILi
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html:         /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-docopt-0.7.0.8-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 docopt
version:              0.7.0.8
visibility:           public
id:                   docopt-0.7.0.8-JLM9l700ffCBegIOFzCXbV
key:                  docopt-0.7.0.8-JLM9l700ffCBegIOFzCXbV
license:              MIT
copyright:            (c) 2013-2015 Ryan Artecona
maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               Ryan Artecona
homepage:             https://github.com/docopt/docopt.hs
synopsis:             A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.

category:             Console
abi:                  f4acd98d13862d7b7fa062b94db2dca5
exposed:              True
exposed-modules:      System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules:
    System.Console.Docopt.ApplicativeParsec
    System.Console.Docopt.ParseUtils System.Console.Docopt.Types
    System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
    System.Console.Docopt.Public System.Console.Docopt.QQ
    System.Console.Docopt.QQ.Instances

import-dirs:          /usr/lib/ghc-9.2.8/site-local/docopt-0.7.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/docopt-0.7.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-docopt
hs-libraries:         HSdocopt-0.7.0.8-JLM9l700ffCBegIOFzCXbV
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html:         /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
